## Welcome to Dathost’s unofficial python wrapper!
This is a unofficial asynchronous & synchronous wrapper for Dathost’s API.

### Features:
- Full API coverage.
- Asynchronous & synchronous support.
- Easy to use with an object oriented design.

### Install
- Pip: ``pip3 install dathost``
- Git: ``pip3 install git+https://github.com/WardPearce/dathost.git``
